@@ -13,7 +13,7 @@ if TYPE_CHECKING:  # pragma: no cover
     from pipen import Proc
     from pipen.job import Job
 
-__version__ = "0.1.0"
+__version__ = "0.1.1"
 
 logger = get_logger("verbose", "info")
 
@@ -113,14 +113,47 @@ class PipenVerbose:
         if proc.envs:
             key_len = max(len(key) for key in proc.envs) if proc.envs else 0
             for key, value in proc.envs.items():
+                value = [
+                    line
+                    if i == 0
+                    else f"{' ' * (len(proc.name) + key_len + 17)}{line}"
+                    for i, line in enumerate(
+                        str(value)
+                        .replace('%', '%%')
+                        .replace('[', '\\[')
+                        .splitlines()
+                    )
+                ]
+
                 proc.log(
                     "info",
                     "envs.%s: %s",
                     key.ljust(key_len),
-                    value,
+                    "\n".join(value),
                     logger=logger,
                 )
 
+        job = proc.jobs[0]
+        # input
+        input = job.input
+        key_len = max(len(inp) for inp in input) if input else 0
+        for inkey, inval in input.items():
+            job.log(
+                "info", "in.%s: %s", inkey.ljust(key_len), inval, logger=logger
+            )
+
+        # output
+        output = job.output
+        key_len = max(len(outp) for outp in output) if output else 0
+        for inkey, inval in output.items():
+            job.log(
+                "info",
+                "out.%s: %s",
+                inkey.ljust(key_len),
+                inval,
+                logger=logger,
+            )
+
         self.tic = time()
 
     @plugin.impl
@@ -173,30 +206,3 @@ class PipenVerbose:
                 job.log("error", "Stdout: %s", job.stdout_file, logger=logger)
                 job.log("error", "Stderr: %s", job.stderr_file, logger=logger)
                 break
-
-    @plugin.impl
-    async def on_job_init(self, proc: "Proc", job: "Job") -> None:
-        """Print input and output for the first job"""
-        # print input/output for the first job
-        if job.index != 0:
-            return
-
-        # input
-        input = job.input
-        key_len = max(len(inp) for inp in input) if input else 0
-        for inkey, inval in input.items():
-            job.log(
-                "info", "in.%s: %s", inkey.ljust(key_len), inval, logger=logger
-            )
-
-        # output
-        output = job.output
-        key_len = max(len(outp) for outp in output) if output else 0
-        for inkey, inval in output.items():
-            job.log(
-                "info",
-                "out.%s: %s",
-                inkey.ljust(key_len),
-                inval,
-                logger=logger,
-            )
